diff --git a/facebook.tgz b/facebook.tgz
index eb199aff..82d4bcc4 100755
Binary files a/facebook.tgz and b/facebook.tgz differ
diff --git a/facebook/README b/facebook/README
index 325f18dd..ee7e489b 100755
--- a/facebook/README
+++ b/facebook/README
@@ -1,15 +1,15 @@
-Installing the Friendika/Facebook connector
+Installing the Friendica/Facebook connector
1. register an API key for your site from developer.facebook.com
- a. We'd be very happy if you include "Friendika" in the application name
- to increase name recognition. The Friendika icons are also present
+ a. We'd be very happy if you include "Friendica" in the application name
+ to increase name recognition. The Friendica icons are also present
in the images directory and may be uploaded as a Facebook app icon.
- Use images/friendika-16.jpg for the Icon and images/friendika-128.jpg for the Logo.
+ Use images/friendica-16.jpg for the Icon and images/friendica-128.jpg for the Logo.
b. The url should be your site URL with a trailing slash.
You may use http://portal.friendika.com/privacy as the privacy policy
URL unless your site has different requirements, and
http://portal.friendika.com as the Terms of Service URL unless
- you have different requirements. (Friendika is a software application
+ you have different requirements. (Friendica is a software application
and does not require Terms of Service, though your installation of it might).
c. Set the following values in your .htconfig.php file
$a->config['facebook']['appid'] = 'xxxxxxxxxxx';
@@ -34,6 +34,6 @@ Facebook contacts will not be able to view private photos, as they are not able
authenticate to your site to establish identity. We will address this
in a future release.
-Info: please make sure that you understand all aspects due to Friendika's
-default licence which is: Creative Commons Attribution 3.0 (further info:
-http://creativecommons.org/licenses/by/3.0/ )
+Info: please make sure that you understand all aspects due to Friendica's
+default licence which is: MIT License (further info:
+https://github.com/friendica/friendica/blob/master/LICENSE)
diff --git a/impressum.tgz b/impressum.tgz
index 901114e5..a8ea7ee0 100755
Binary files a/impressum.tgz and b/impressum.tgz differ
diff --git a/impressum/README b/impressum/README
index 8e4255bd..3f183fbf 100755
--- a/impressum/README
+++ b/impressum/README
@@ -1,12 +1,12 @@
-Impressum Plugin for Friendika
+Impressum Plugin for Friendica
Author: Tobias Diekershoff
tobias.diekershoff@gmx.net
-License: 3-clause BSD license (same as Friendika)
+License: 3-clause BSD license (same as Friendica)
About
- This plugin adds an Impressum block to the /friendika page with informations
+ This plugin adds an Impressum block to the /friendica page with informations
about the page operator/owner and how to contact you in case of any questions.
In the notes and postal fields you can use HTML tags for formatting.
@@ -14,7 +14,7 @@ About
Configuration:
For configuration you can set the following variables in the .htconfig file
* $a->config['impressum']['owner'] this is the Name of the Operator
- * $a->config['impressum']['ownerprofile'] this is an optional Friendika account
+ * $a->config['impressum']['ownerprofile'] this is an optional Friendica account
where the above owner name will link to
* $a->config['impressum']['email'] a contact email address (optional)
will be displayed slightly obfuscated
diff --git a/impressum/impressum.php b/impressum/impressum.php
index b760c7e0..ce9790bb 100755
--- a/impressum/impressum.php
+++ b/impressum/impressum.php
@@ -1,7 +1,7 @@
* License: 3-clause BSD license
diff --git a/ldapauth.tgz b/ldapauth.tgz
index 300a27b1..28bbed62 100755
Binary files a/ldapauth.tgz and b/ldapauth.tgz differ
diff --git a/ldapauth/README b/ldapauth/README
index cf28ef1e..90ee2595 100755
--- a/ldapauth/README
+++ b/ldapauth/README
@@ -4,8 +4,8 @@ to maintain a single password across the organisation.
Optionally authenticates only if a member of a given group in the directory.
-The person must have registered with Friendika using the normal registration
-procedures in order to have a Friendika user record, contact, and profile.
+The person must have registered with Friendica using the normal registration
+procedures in order to have a Friendica user record, contact, and profile.
Note when using with Windows Active Directory: you may need to set TLS_CACERT in your site
ldap.conf file to the signing cert for your LDAP server.
diff --git a/ldapauth/ldapauth.php b/ldapauth/ldapauth.php
index 7230302e..b87f669d 100755
--- a/ldapauth/ldapauth.php
+++ b/ldapauth/ldapauth.php
@@ -7,7 +7,7 @@
*/
/**
- * Friendika addon
+ * Friendica addon
*
* Module: LDAP Authenticate
*
@@ -17,8 +17,8 @@
*
* Optionally authenticates only if a member of a given group in the directory.
*
- * The person must have registered with Friendika using the normal registration
- * procedures in order to have a Friendika user record, contact, and profile.
+ * The person must have registered with Friendica using the normal registration
+ * procedures in order to have a Friendica user record, contact, and profile.
*
* Note when using with Windows Active Directory: you may need to set TLS_CACERT in your site
* ldap.conf file to the signing cert for your LDAP server.
diff --git a/piwik.tgz b/piwik.tgz
index 1b2a4823..54752c6e 100755
Binary files a/piwik.tgz and b/piwik.tgz differ
diff --git a/piwik/README b/piwik/README
index 20b78b51..d5060d0b 100755
--- a/piwik/README
+++ b/piwik/README
@@ -3,7 +3,7 @@ by Tobias Diekershoff
tobias.diekershoff(at)gmx.net
This addon allows you to embed the code necessary for the FLOSS webanalytics
-tool piwik into the Friendika pages.
+tool piwik into the Friendica pages.
Online version of this Document: http://ur1.ca/35m2x
@@ -13,7 +13,7 @@ To use this plugin you need a "piwik":http://piwik.org installation.
___ Where to find ___
-In the Friendika git repository @/addon/piwik/piwik.php@ and a CSS file for
+In the Friendica git repository @/addon/piwik/piwik.php@ and a CSS file for
styling the opt-out notice.
___ Configuration ___
@@ -29,9 +29,9 @@ $a->config['piwik']['optout'] = true;
The *baseurl* points to your piwik installation. Use the absolute path,
remember trailing slashes but ignore the protocol (http/s) part of the URL.
Change the *sideid* parameter to whatever ID you want to use for tracking your
-Friendika installation. The *optout* parameter (true|false) defines whether or
+Friendica installation. The *optout* parameter (true|false) defines whether or
not a short notice about the utilization of piwik will be displayed on every
-page of your Friendika site (at the bottom of the page with some spacing to the
+page of your Friendica site (at the bottom of the page with some spacing to the
other content). Part of the note is a link that allows the visitor to set an
_opt-out_ cookie which will prevent visits from that user be tracked by piwik.
diff --git a/piwik/piwik.php b/piwik/piwik.php
index 890309d4..5a46cdb3 100755
--- a/piwik/piwik.php
+++ b/piwik/piwik.php
@@ -1,13 +1,13 @@
*/
-/* Piwik Analytics Plugin for Friendika
+/* Piwik Analytics Plugin for Friendica
*
* Author: Tobias Diekershoff
* tobias.diekershoff@gmx.net
@@ -21,7 +21,7 @@
* $a->config['piwik']['siteid'] = '1';
* $a->config['piwik']['optout'] = true; // set to false to disable
*
- * Change the siteid to the ID that the Piwik tracker for your Friendika
+ * Change the siteid to the ID that the Piwik tracker for your Friendica
* installation has. Alter the baseurl to fit your needs, don't care
* about http/https but beware to put the trailing / at the end of your
* setting.
@@ -45,7 +45,7 @@ function piwik_analytics($a,&$b) {
/*
* styling of every HTML block added by this plugin is done in the
- * associated CSS file. We just have to tell Friendika to get it
+ * associated CSS file. We just have to tell Friendica to get it
* into the page header.
*/
$a->page['htmlhead'] .= '' . "\r\n";
diff --git a/randplace.tgz b/randplace.tgz
index c5faeb40..937c02d5 100755
Binary files a/randplace.tgz and b/randplace.tgz differ
diff --git a/randplace/randplace.php b/randplace/randplace.php
index bae8e7c6..35503850 100755
--- a/randplace/randplace.php
+++ b/randplace/randplace.php
@@ -1,7 +1,7 @@
*
diff --git a/twitter.tgz b/twitter.tgz
index ac3d5f19..740e3c81 100755
Binary files a/twitter.tgz and b/twitter.tgz differ
diff --git a/twitter/README b/twitter/README
index e6d5f12c..99edf0d3 100755
--- a/twitter/README
+++ b/twitter/README
@@ -7,7 +7,7 @@ By Tobias Diekershoff
!! with it, please contact the Author. !!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-With this addon to Friendika you can give your user the possibility to post
+With this addon to Friendica you can give your user the possibility to post
their *public* messages to Twitter. The messages will be strapped their rich
context and shortened to 140 characters length if necessary. If shortening of
the message was performed a link will be added to the Tweet pointing to the
@@ -20,7 +20,7 @@ Online version of this document: http://ur1.ca/35mml
___ Requirements ___
-To use this plugin you have to register your Friendika instance as an
+To use this plugin you have to register your Friendica instance as an
_client application_ for Twitter with _read and write_ access, we do not intend
to use Twitter for login. The registration can be done at twitter.com/apps
and you need to have a Twitter account to do so.
@@ -34,7 +34,7 @@ message was longer than 140 characters requires it, that you have *PHP5+* and
___ Where to find ___
-In the Friendika git repository /addon/twitter/, this directory contains
+In the Friendica git repository /addon/twitter/, this directory contains
all required PHP files (including the Twitter OAuth library [1] by Abraham
Williams, MIT licensed and the Slinky library [2] by Beau Lebens, BSD license),
a CSS file for styling of the user configuration and an image to _Sign in with
@@ -68,7 +68,7 @@ connect to Twitter. To do so one has to follow the _Sign in with Twitter_
button (the page will be opened in a new browser window/tab) and get a PIN from
Twitter. This PIN has to be entered on the settings page. After submitting the
PIN the plugin will get OAuth credentials identifying this user from the
-Friendika account.
+Friendica account.
If this first step was successful the Twitter configuration will be changed
on the "Plugin Settings" page displaying two check boxes. One to enable/disable
diff --git a/uhremotestorage.tgz b/uhremotestorage.tgz
index 2654cd03..9e91f49a 100755
Binary files a/uhremotestorage.tgz and b/uhremotestorage.tgz differ
diff --git a/uhremotestorage/uhremotestorage.php b/uhremotestorage/uhremotestorage.php
index 5c182004..30600369 100755
--- a/uhremotestorage/uhremotestorage.php
+++ b/uhremotestorage/uhremotestorage.php
@@ -53,7 +53,7 @@ function uhremotestorage_settings($a, &$s){
$tpl = file_get_contents(dirname(__file__)."/settings.tpl");
$s .= replace_macros($tpl, array(
'$title' => 'Unhosted remote storage',
- '$desc' => sprintf( t('Allow to use your friendika id (%s) to connecto to external unhosted-enabled storage (like ownCloud)'), $uid ),
+ '$desc' => sprintf( t('Allow to use your friendica id (%s) to connecto to external unhosted-enabled storage (like ownCloud)'), $uid ),
'$url' => array( 'unhoestedurl', t('Unhosted DAV storage url'), $davurl, 'If your are using ownCloud, your unhosted url will be like http://HOST/apps/remoteStorage/compat.php/USER/remoteStorage/'),
'$submit' => t('Submit'),
));
diff --git a/widgets.tgz b/widgets.tgz
index 863efd0a..416f08cb 100755
Binary files a/widgets.tgz and b/widgets.tgz differ
diff --git a/widgets/widgets.php b/widgets/widgets.php
index 226a34c0..27cabfd6 100755
--- a/widgets/widgets.php
+++ b/widgets/widgets.php
@@ -1,7 +1,7 @@
*/
diff --git a/sniper.tgz b/sniper.tgz
index 693fa51c..2481d0b8 100755
Binary files a/sniper.tgz and b/sniper.tgz differ
diff --git a/sniper/sniper.php b/sniper/sniper.php
index 276748fe..59812cba 100755
--- a/sniper/sniper.php
+++ b/sniper/sniper.php
@@ -1,7 +1,7 @@
Connections -> Register an OAuth client application
-> Register a new application".
@@ -64,12 +64,12 @@ During the registration of the OAuth client remember the following:
* there is no callback url
* register a desktop client
* with read & write access
* the Source URL should be the URL of your Friendika server
After the required credentials for the application are stored in the
-configuration you have to actually connect your Friendika account with
+configuration you have to actually connect your Friendica account with
StatusNet. To do so follow the Sign in with StatusNet button, allow the access
-and copy the security code into the plugin configuration. Friendika will then
+and copy the security code into the plugin configuration. Friendica will then
try to acquire the final OAuth credentials from the API, if successful the
plugin settings will allow you to select to post your public messages to your
StatusNet account.
@@ -64,12 +64,12 @@ During the registration of the OAuth client remember the following:
* register a desktop client
* with read & write access
- * the Source URL should be the URL of your Friendika server
+ * the Source URL should be the URL of your Friendica server
After the required credentials for the application are stored in the